@@ -7,8 +7,14 @@ alias @assets=bluer_sandbox_assets
 
 alias @docker=bluer_sandbox_docker
 
-alias @offline_llm=bluer_sandbox_offline_llm
-
 alias @notebooks=bluer_sandbox_notebooks
 
+alias @parser=bluer_sandbox_parser
+
+alias @offline_llm=bluer_sandbox_offline_llm
+alias @ollm=bluer_sandbox_offline_llm
+alias @llm=bluer_sandbox_offline_llm
+
 alias @sandbox=bluer_sandbox
+
+alias @speedtest=bluer_sandbox_speedtest
