@@ -7,7 +7,6 @@ function test_bluer_sandbox_help() {
     for module in \
         "@arvan" \
         "@arvan seed" \
-        "@arvan set_ip" \
         "@arvan ssh" \
         \
         "@assets" \
@@ -39,6 +38,9 @@ function test_bluer_sandbox_help() {
         "@offline_llm model get" \
         "@offline_llm prompt" \
         \
+        "@parser" \
+        "@parser parse" \
+        \
         "@sandbox" \
         \
         "@sandbox pypi" \
@@ -51,6 +53,8 @@ function test_bluer_sandbox_help() {
         "@sandbox test" \
         "@sandbox test list" \
         \
+        "@speedtest" \
+        \
         "bluer_sandbox"; do
         bluer_ai_eval ,$options \
             bluer_ai_help $module
